#!/usr/bin/env python
''' yamlcfg.env

Checks the environment for declared variables.
'''

import os
from yamlcfg.util import normalize

def check_env(var, **kwargs):
    getenv = os.getenv(var)
    if getenv:
        return normalize(getenv, **kwargs)



#!/usr/bin/env python
''' yamlcfg

Bring in Configs into namespace
'''

from yamlcfg.conf import Config as BaseConfig
from yamlcfg.yml import YAMLConfig
YMLConfig = YAMLConfig
YamlConfig = YAMLConfig

from yamlcfg.util import normalize, validate_ext

from yamlcfg.env import check_env



#!/usr/bin/env python
''' yamlcfg.conf

Base config
'''

import os
from yamlcfg import env

class Config(object):

    def __init__(self, path=None, paths=None):
        if path is None:
            self._path = None
        else:
            self._path = os.path.expanduser(path)
        if paths is None:
            self._paths = None
        else:
            self._paths = [os.path.expanduser(x) for x in paths] 
        self._data = {}

    def open(self, path=None, paths=None):
        if path is not None:
            self._path = os.path.expanduser(path)
        if paths is not None:
            self._paths = [os.path.expanduser(x) for x in paths]

    def __getattr__(self, attr):
        return self[attr]
    
    def __getitem__(self, index):
        check_env = env.check_env(index)
        if check_env is not None:
            return check_env
        if index in self._data:
            return self._data[index]

    def __setattr__(self, attr, value):
        if attr in ('_data', '_path', '_paths'):
            super(Config, self).__setattr__(attr, value)
        else:
            self._data[attr] = value



#!/usr/bin/env python
''' yamlcfg.yml

Parse YAML configs
'''

import os
import yaml

from yamlcfg.conf import Config
from yamlcfg.util import validate_ext

def is_yaml(path):
    return validate_ext(path, ('yaml', 'yml'))

class YAMLConfig(Config):
    
    def __init__(self, *args, **kwargs):
        super(YAMLConfig, self).__init__(*args, **kwargs)
        if self._path or self._paths:
            self.open(path=self._path, paths=self._paths)

    def open(self, path=None, paths=None):
        super(YAMLConfig, self).open(path=path, paths=paths)
        if paths is not None:
            self.parse_paths(paths)
        if path is not None:
            self.parse_path(path)

    def parse_path(self, path):
        with open(path) as f:
            self._data.update(yaml.load(f))

    def parse_paths(self, paths):
        for path in paths[::-1]:
            if os.path.exists(path):
                with open(path) as f:
                    data = yaml.load(f)
                    self._data.update(data)

    def write(self, path=None):
        if path is None:
            path = self._path
        if path is None:
            path = self._paths[0]
        if path is None:
            raise ValueError('No path passed to write, and no paths already '
                'passed on initialization or YAMLConfig.open')
        with open(path, 'w') as f:
            f.write(yaml.dump(self._data, default_flow_style=False))



#!/usr/bin/env python
''' yamlcfg.util

Cross module utilities
'''
import os

def normalize(var, type=None, **kwargs):
    if var is None:
        return None
    if type is None:
        return var
    if type is basestring:
        return str(type)
    elif type is int:
        return int(type)
    elif type is hex:
        return int(type, 16)
    elif type is bin:
        return int(type, 2)
    elif type is oct:
        return int(type, 8)
    else:
        raise ValueError('Unrecognized type argument. '
            'Cannot normalize variable.')

def validate_ext(path, valid_ext):
    path, ext = os.path.splitext(path)
    if ext.startswith('.'):
        ext = ext[1:].lower()
    if isinstance(valid_ext, basestring):
        return ext == valid_ext.lower()
    elif hasattr(valid_ext, '__contains__'):
        return ext in {x.lower() for x in valid_ext}
    else:
        raise ValueError('valid_ext must be either a string or implement '
            '__contains__')



import os
from setuptools import setup

# yamlcfg
# Hierarchical configuration parser

def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()

setup(
    name = "yamlcfg",
    version = "0.2.0",
    description = "Hierarchical configuration parser",
    author = "Johan Nestaas",
    author_email = "johan@riskiq.net",
    license = "BSDv2",
    keywords = "config, configuration, cfg, yaml, yml",
    #url = "https://www.github.com/RiskIQ/yamlcfg
    packages=['yamlcfg'],
    package_dir={'yamlcfg': 'yamlcfg'},
    long_description=read('README.md'),
    classifiers=[
        #'Development Status :: 1 - Planning',
        #'Development Status :: 2 - Pre-Alpha',
        'Development Status :: 3 - Alpha',
        #'Development Status :: 4 - Beta',
        #'Development Status :: 5 - Production/Stable',
        #'Development Status :: 6 - Mature',
        #'Development Status :: 7 - Inactive',
        'License :: OSI Approved :: BSD License',
        'Environment :: Console',
        'Environment :: X11 Applications :: Qt',
        'Environment :: MacOS X',
        'Environment :: Win32 (MS Windows)',
        'Operating System :: POSIX',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Programming Language :: Python',
    ],
    install_requires=[
        'pyyaml',
    ],
    entry_points = {
        'console_scripts': [
            'yamlcfg = yamlcfg.bin:yamlcfg',
        ],
    },
    #package_data = {
        #'yamlcfg': ['catalog/*.edb'],
    #},
    #include_package_data = True,
)
